#!/bin/sh
#*******************************************************************************
# Licensed Materials - Property of IBM
# (c) Copyright IBM Corporation 2013. All Rights Reserved.
#
# Note to U.S. Government Users Restricted Rights:  
# Use, duplication or disclosure restricted by GSA ADP Schedule 
# Contract with IBM Corp. 
#*******************************************************************************

#
# Rational Team Concert Build System Toolkit install script
#
# copyright @ 2001-2012 IBM, Inc.
# all rights reserved.
#


#
# Figure out whether we'll be using ps -ef or ps augwwwx when we want to
# search for a process.
#
if ps -ef >/dev/null 2>&1; then
	PS_FLAGS="-ef"
else
	PS_FLAGS="augwwwx"
fi

#
# set the default install directory
#
default_dest="/usr/local/bin"
for dir in /usr/sbin /sbin /bin /usr/bin /usr/local/bin
do
	if [ -d $dir ]
	then
		default_dest=$dir
	fi
done

#
# set the $ECHO flags
#
ECHO="/bin/echo"
$ECHO -n hello | grep n > /dev/null
if [ $? -eq 0 ]
then
	ECHO_N=""
	ECHO_C="\c"
else
	ECHO_N="-n"
	ECHO_C=""
fi

#
# must be root to set up agent processes
#
id | grep root > /dev/null 2>&1
if [ $? -ne 0 ]; then
	$ECHO ""
	$ECHO "***"
	$ECHO "*** You must be root to install the IBM Rational Team Concert Build System Toolkit."
	$ECHO "***"
## FIXME	exit 1
fi

if [ -z "$AGENT_PORT" -a -z "$AGENT_DIR" ]; then
	cat <<EOF

Welcome to the IBM Rational Team Concert Build System Toolkit installation script.
This script will install the IBM Rational Team Concert Build System Toolkit Service.

Press return to continue ...
EOF
	read junk
	$ECHO ""
fi

#
# Require license approval
#
if [ ! -f LICENSE.txt ]
then
	$ECHO ""
	$ECHO "ERROR: Unable to find license text to display."
	$ECHO "You may not install without accepting a license agreement."
	$ECHO ""
	$ECHO "Installation aborted."
	$ECHO ""
	exit 3
fi

response=
while [ -z "$response" ]; do
	$ECHO ""
	$ECHO "You must accept the license agreement to install this software."
	$ECHO "Enter nothing to display the license, or 'YES' to accept it."
	$ECHO "Any other response will terminate the installation."
	$ECHO ""
	$ECHO $ECHO_N "Do you accept this license? $ECHO_C"
	read response
	if [ -z "$response" ]; then
		cat LICENSE.txt
	fi
done

if [ "x$response" != "xYES" ]; then
	$ECHO ""
	$ECHO "You must accept the license agreement to install this software."
	$ECHO ""
	$ECHO "Installation aborted."
	$ECHO ""
	exit 4
fi

ser=`date "+%Y%m%d%H%M"`."$$"


#
# Make sure xinetd or inetd is available.
#
iss_type=
iss_pid=
iss_file=
iss_name=
if [ -f /etc/inetd.conf ]; then
	iss_pid=`ps $PS_FLAGS | grep inetd | grep -v grep | awk 'NR==1 {print $2}'`
	if [ -n "$iss_pid" ]; then
		iss_type="inetd"
		iss_name="bfagent"
		iss_file="/etc/inetd.conf"
	fi
fi
if [ -d /etc/xinetd.d ]; then
	iss_pid=`ps $PS_FLAGS | grep xinetd | grep -v grep | awk 'NR==1 {print $2}'`
	if [ -n "$iss_pid" ]; then
		iss_type="xinetd"
		iss_name="bfagent"
		iss_file="/etc/xinetd.d/$iss_name"
	fi
fi
if [ -z "$iss_type" ]; then
	$ECHO ""
	$ECHO "ERROR: No internet super-server seems to be installed!"
	$ECHO ""
	$ECHO "This script understands the inetd and xinetd internet"
	$ECHO "super-servers, but it was not able to find any of them on this"
	$ECHO "system."
	$ECHO ""
	$ECHO "Installation aborted."
	$ECHO ""
	exit 2
fi

case $iss_type in
	xinetd)
		set -e
		(
			cat <<EOF
# default: on
service bfagent
{
	socket_type	= stream
	wait		= no
	user		= root
	server		= ${PWD}/startbfa.sh
	flags 		= IPV6
	log_on_success += HOST DURATION
	log_on_failure += HOST
	passenv		=
	disable		= no
}
EOF
		) \
		| sed -e "s,${PWD},$dest,g" \
		> /etc/xinetd.d/bfagent
		set +e
		$ECHO "IBM Rational Team Concert Build System Toolkit Service definition created as $iss_file"
		;;

	inetd)
		cp /etc/inetd.conf /etc/inetd.conf.$ser
		grep -v "^bfagent[ 	]" /etc/inetd.conf.$ser > /etc/inetd.conf
		set -e
		$ECHO "bfagent stream tcp nowait root ${PWD}/startbfa.sh bfagent" \
			| sed -e "s,_BF_BINDIR_,$dest,g" \
			>> /etc/inetd.conf
		$ECHO "bfagent stream tcp6 nowait root ${PWD}/startbfa.sh bfagent" \
			| sed -e "s,_BF_BINDIR_,$dest,g" \
			>> /etc/inetd.conf
		set +e
		$ECHO "IBM Rational Team Concert Build System Toolkit definition added to $iss_file"
		if [ -s /etc/inetd.conf ]; then
			rm -f /etc/inetd.conf.$ser
		else
			$ECHO "ERROR: Unable to update /etc/inetd.conf"
			$ECHO "Original file is at /etc/inetd.conf.$ser"
		fi
		;;
esac

# Make sure we have a PAM configuration if PAM seems to be there.  We will
# use sshd's entries as a template if they are there; otherwise, fall back
# on login's.

if [ -d /etc/pam.d ]; then
	if [ ! -f /etc/pam.d/bfagent ]; then
		set -e
		if [ -f /etc/pam.d/sshd ]; then
			cp /etc/pam.d/sshd /etc/pam.d/bfagent
		else
			cp /etc/pam.d/login /etc/pam.d/bfagent
		fi
		set +e
		$ECHO "***"
		$ECHO "*** Please verify that the PAM entries in /etc/pam.d/bfagent"
		$ECHO "*** conform to your local security policies."
		$ECHO "***"
	fi
elif [ -f /etc/pam.conf ]; then
	cp /etc/pam.conf /etc/pam.conf.$ser
	grep -v bfagent /etc/pam.conf.$ser > /etc/pam.conf

	# duplicate either the sshd or login auth entries
	if grep "^sshd[ 	][ 	]*auth[ 	]" /etc/pam.conf.$ser >/dev/null 2>&1; then
		copy_from=sshd
	else
		copy_from=login
	fi
	grep "^${copy_from}[ 	][ 	]*auth[ 	]" /etc/pam.conf.$ser \
		| sed -e "s/^${copy_from}/bfagent/" \
		| grep -v pam_dial_auth \
		>> /etc/pam.conf

	# Now do the same for the account entries ...
	if grep "^sshd[ 	][ 	]*account[ 	]" /etc/pam.conf.$ser >/dev/null 2>&1; then
		copy_from=sshd
	else
		copy_from=login
	fi
	grep "^${copy_from}[ 	][ 	]*account[ 	]" /etc/pam.conf.$ser \
		| sed -e "s/^${copy_from}/bfagent/" \
		| grep -v pam_dial_auth \
		>> /etc/pam.conf

	$ECHO "***"
	$ECHO "*** Please verify that the bfagent PAM entries in /etc/pam.conf"
	$ECHO "*** conform to your local security policies."
	$ECHO "***"
	if [ -s /etc/pam.conf ]; then
		rm -f /etc/pam.conf.$ser
	else
		$ECHO "ERROR: unable to update /etc/pam.conf"
		$ECHO "Original file is at /etc/pam.conf.$ser"
		exit 1
	fi
fi

$ECHO "IBM Rational Team Concert Build System Toolkit Installation Complete."

exit 0

